#!/usr/bin/python
# Requires python3, BioPython 1.61+
# Adam Caldwell 20130515

from Bio import SeqIO
import collections
import csv

contigs_fasta = "/data/supplemental_data_code/DatasetS2_contigs.fasta"
phymmbl_data = "/data/supplemental_data_code/DatasetS3_phymmbl.tsv"
metaxa_fasta = "/data/supplemental_data_code/DatasetS4_metaxa.bacteria.fasta"
metaxa_RDP = "/data/supplemental_data_code/DatasetS5_RDP.txt"

len_dict_contigs = dict()

for record in SeqIO.parse(open(contigs_fasta, "r"), "fasta"):
    len_dict_contigs[record.id] = len(record)

phylum_dict_phymmbl = collections.defaultdict(int)

with open(phymmbl_data, "r") as phymmbl_file:
    phymmblreader = csv.reader(phymmbl_file, delimiter='\t')
    for row in phymmblreader:
        if row[0] == "QUERY_ID":
            pass
        elif row[11] == "":
            phylum_dict_phymmbl["NO_PHYLUM"] += len_dict_contigs[row[0]]
        else:
            phylum_dict_phymmbl[row[11]] += len_dict_contigs[row[0]]

len_dict_metaxa = dict()

for record in SeqIO.parse(open(metaxa_fasta, "r"), "fasta"):
    len_dict_metaxa[record.id] = len(record)

phylum_dict_metaxa = collections.defaultdict(int)

with open(metaxa_RDP, "r") as RDP_file:
    RDPreader = csv.reader(RDP_file, delimiter=';')
    for row in RDPreader:
        if len(row) < 2:
            pass
        else:
            phylum_dict_metaxa[row[6]] += len_dict_metaxa[row[0]]

with open("DatasetS6_phylogeny_comparison_bp.tsv", "w") as outfile:   
    print("Program", "Phylum", "bp", sep="\t", file=outfile)

    for phylum, bp in phylum_dict_phymmbl.items():
        print("PhymmBL", phylum, bp, sep="\t", file=outfile)

    for phylum, bp in phylum_dict_metaxa.items():
        print("Metaxa", phylum, bp, sep="\t", file=outfile)
